/*
**
**	$Id: StripISO.c,v 1.0 1995/09/13 12:18:26 peter Exp $
**	$Revision: 1.0 $
**
**	$Filename: StripISO.c $
**	$Author: Peter W. Simeon $
**	$Release: $
**	$Date: 1995/09/13 12:18:26 $
**
**	StripISO - Replaces all ISO characters with ASCII counterparts
**
**	COPYRIGHT (C) 1994 BY PETER W. SIMEON, ZUERICH. ALL RIGHTS RESERVED.
**	NO PART OF THIS SOFTWARE MAY BE COPIED, REPRODUCED, OR TRANSMITTED
**	IN ANY FORM OR BY ANY MEANS,  WITHOUT THE PRIOR WRITTEN PERMISSION
**	OF PETER W. SIMEON.
**
*/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>

char VersionString[] = "$VER: StripISO 1.0 (13 Sep 95) by Peter W. Simeon";

int FirstChar[] =
{
	'!', 'c', 'U', ' ', 'Y', '|', ' ', ' ', '(', ' ', '"', '-', '-',
	'(', '-', ' ', '+', '^', '^', '\'', 'u', 'P', '-', ' ', '1', ' ',
	'"', '1', '1', '1', '?', 'A', 'A', 'A', 'A', 'A', 'A', 'A', 'C',
	'E', 'E', 'E', 'E', 'I', 'I', 'I', 'I', 'D', 'N', 'O', 'O', 'O',
	'O', 'O', 'x', 'O', 'U', 'U', 'U', 'U', 'Y', 'p', 's', 'a', 'a',
	'a', 'a', 'a', 'a', 'a', 'c', 'e', 'e', 'e', 'e', 'i', 'i', 'i', 
	'i', 'o', 'n', 'o', 'o', 'o', 'o', 'o', '/', 'o', 'u', 'u', 'u',
	'u', 'y', 'p', 'y'
};

struct ISOTable
{
	int		Input;
	int		Output;
};

struct ISOTable SecondChar[] =
{
	{ 163, 'K' },
	{ 169, 'C' },
	{ 174, 'R' },
	{ 177, '/' },
	{ 178, '2' },
	{ 179, '3' },
	{ 182, 'I' },
	{ 188, '/' },
	{ 189, '/' },
	{ 190, '/' },
	{ 196, 'e' },
	{ 198, 'e' },
	{ 214, 'e' },
	{ 220, 'e' },
	{ 223, 's' },
	{ 228, 'e' },
	{ 230, 'e' },
	{ 246, 'e' },
	{ 246, 'e' },
	{ 252, 'e' },
	{ 256, ' ' }
};

struct ISOTable ThirdChar[] =
{
	{ 163, '#' },
	{ 169, ')' },
	{ 174, ')' },
	{ 177, '-' },
	{ 188, '4' },
	{ 189, '2' },
	{ 190, '4' },
	{ 256, ' ' }
};


void StripISO(FILE *in, FILE *out)
{
	int		ch;
	int		i;

	while((ch = getc(in)) != EOF)
	{
		if(ch < 128)
		{
			putc(ch, out);		/* Standard ASCII code */
		}
		else
		{
			if(ch < 161)		/* Replace control characters with space */
			{
				putc(' ', out);
			}
			else
			{
				putc(FirstChar[ch-161], out);		/* First character */

				i = 0;								/* Check for second char */
				while(SecondChar[i].Input < ch)
					i++;
				if(ch == SecondChar[i].Input)
					putc(SecondChar[i].Output, out);

				i = 0;								/* Check for third char */
				while(ThirdChar[i].Input < ch)
					i++;
				if(ch == ThirdChar[i].Input)
					putc(ThirdChar[i].Output, out);
			}
		}
	}
}


void main(int argc, char *argv[])
{
	FILE	*infp, *outfp;

	switch(argc)
	{
		case 1:
			StripISO(stdin, stdout);
			exit(0);

		case 2:
			if(argv[1][0] == '?')
				printf("Usage: stripiso [<infile>] [<outfile>]\n");
			else
			{
				if(infp = fopen(argv[1], "r"))
				{
					StripISO(infp, stdout);
					fclose(infp);
				}
				else
					printf("Can't open input file\n");
			}
			exit(0);

		case 3:
			if(infp = fopen(argv[1], "r"))
			{
				if(outfp = fopen(argv[2], "w"))
				{
					StripISO(infp, outfp);
					fclose(outfp);
				}
				else
					printf("Can't open output file\n");
				fclose(infp);
			}
			else
				printf("Can't open input file\n");
			exit(0);

		default:
			printf("Usage: stripiso [<infile>] [<outfile>]\n");			
	}
}

